==> xfwm4-4.4.2.tar.bz2: xfwm4-4.4.2/src/workspaces.h <==
/*      $Id: workspaces.h 24099 2006-12-13 22:01:17Z olivier $

        This program is free software; you can redistribute it and/or modify
        it under the terms of the GNU General Public License as published by
        the Free Software Foundation; either version 2, or (at your option)
        any later version.

        This program is distributed in the hope that it will be useful,
        but WITHOUT ANY WARRANTY; without even the implied warranty of
        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
        GNU General Public License for more details.

        You should have received a copy of the GNU General Public License
        along with this program; if not, write to the Free Software
        Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

        oroborus - (c) 2001 Ken Lynch
        xfwm4    - (c) 2002-2006 Olivier Fourdan

 */

#ifndef INC_WORKSPACES_H
#define INC_WORKSPACES_H

#ifdef HAVE_CONFIG_H
#  include "config.h"
#endif

#include <X11/X.h>
#include <X11/Xlib.h>
#include <X11/Xutil.h>
#include <X11/Xmd.h>
#include <glib.h>

#include "screen.h"
#include "client.h"

gboolean                workspaceMove                           (ScreenInfo *, 
                                                                 int, 
                                                                 int, 
                                                                 Client *,
                                                                 Time);
void                    workspaceSwitch                         (ScreenInfo *, 
                                                                 int, 
                                                                 Client *, 
                                                                 gboolean,
                                                                 Time);
void                    workspaceSetNames                       (ScreenInfo *, 
                                                                 gchar **, 
                                                                 int);
void                    workspaceSetCount                       (ScreenInfo *, 
                                                                 int);
void                    workspaceUpdateArea                     (ScreenInfo *);

#endif /* INC_WORKSPACES_H */

==> xfwm4-4.5.91.tar.bz2: xfwm4-4.5.91/src/workspaces.h <==
/*      $Id: workspaces.h 26999 2008-05-31 14:35:42Z olivier $

        This program is free software; you can redistribute it and/or modify
        it under the terms of the GNU General Public License as published by
        the Free Software Foundation; either version 2, or (at your option)
        any later version.

        This program is distributed in the hope that it will be useful,
        but WITHOUT ANY WARRANTY; without even the implied warranty of
        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
        GNU General Public License for more details.

        You should have received a copy of the GNU General Public License
        along with this program; if not, write to the Free Software
        Foundation, Inc., Inc., 51 Franklin Street, Fifth Floor, Boston,
        MA 02110-1301, USA.


        oroborus - (c) 2001 Ken Lynch
        xfwm4    - (c) 2002-2008 Olivier Fourdan

 */

#ifndef INC_WORKSPACES_H
#define INC_WORKSPACES_H

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <X11/X.h>
#include <X11/Xlib.h>
#include <X11/Xutil.h>
#include <X11/Xmd.h>
#include <glib.h>

#include "screen.h"
#include "client.h"

gboolean                workspaceMove                           (ScreenInfo *,
                                                                 int,
                                                                 int,
                                                                 Client *,
                                                                 Time);
void                    workspaceSwitch                         (ScreenInfo *,
                                                                 int,
                                                                 Client *,
                                                                 gboolean,
                                                                 Time);
void                    workspaceSetNames                       (ScreenInfo *,
                                                                 gchar **,
                                                                 int);
void                    workspaceSetCount                       (ScreenInfo *,
                                                                 int);
void                    workspaceUpdateArea                     (ScreenInfo *);

void                    workspaceInsert                         (ScreenInfo *,
                                                                 int);

void                    workspaceDelete                         (ScreenInfo *,
                                                                 int);

#endif /* INC_WORKSPACES_H */
